@@ -26,7 +26,7 @@ module FileUtils
   private_class_method :futilsmsg
 
 
-  FU = FileUtilities
+  FU = FILEUTILS
 
   def cd( dn )
     if iterator? then
@@ -218,7 +218,7 @@ module FileUtils
 
   def chmod( mode, *args )
     args.flatten!
-    futilsmsg "chmod #{mode ? '%o ' % mode : ''}#{args.join ' '}" if @verbose
+    futilsmsg sprintf('chmod %o %s', mode, args.join(' ')) if @verbose
     File.chmod mode, *args
   end
 
