@@ -1,7 +1,7 @@
 #
 # mails.rb
 #
-#   Copyright (c) 1999 Minero Aoki <aamine@dp.u-netsurf.ne.jp>
+#   Copyright (c) 1999,2000 Minero Aoki <aamine@dp.u-netsurf.ne.jp>
 #
 #   This program is free software.
 #   You can distribute/modify this program under the terms of
@@ -97,7 +97,7 @@ class MailScanner < Racc::Scanner
             sret = :DIGIT
             vret = vret
 
-          elsif @m_recv = :MODE_RECV then
+          elsif @m_recv == :MODE_RECV then
             case vret.downcase
             when 'from' then sret = :FROM
             when 'by'   then sret = :BY
