@@ -12,8 +12,8 @@ require 'nkf'
 
 require 'amstd/to_s'
 require 'amstd/bug'
-require 'amstd/must'
 
+require 'tmail/info'
 require 'tmail/field'
 require 'tmail/port'
 require 'tmail/loader'
@@ -25,8 +25,6 @@ class MailError < StandardError ; end
 
 module TMail
 
-  Version = '0.8.5'
-
 
 class Mail
 
@@ -132,15 +130,15 @@ class Mail
     accept stra, eol, ret, sep
     ret
   end
-  alias to_s encoded
 
   def decoded( eol = "\n", charset = 'e', ret = '', sep = '' )
     stra = HFdecoder.new( ret, charset )
     accept stra, eol, ret, sep
     ret
   end
+
+  alias to_s encoded
   alias inspect decoded
-  
   # def inspect
   #   "#<TMail::Mail: @port=#{@port.inspect}, @body=#{@body_port.inspect}>"
   # end
@@ -214,7 +212,7 @@ class Mail
       end
       if initbody then
         ret = mkhf( *ret.split(':', 2) )
-        store dkey, ret
+        do_store dkey, ret
       end
     end
 
@@ -242,9 +240,14 @@ class Mail
       @header[dkey] = val
       return
     else
-      val.must HeaderField, String, Array
+      val = mkhf( key, val.to_s )
     end
 
+    do_store dkey, val
+  end
+  alias []= store
+
+  def do_store( dkey, val )
     if USE_ARRAY.include? dkey then
       if arr = @header[dkey] then
         arr.push val
@@ -255,7 +258,7 @@ class Mail
       @header[dkey] = val
     end
   end
-  alias []= store
+  private :do_store
 
 
   def each_header
@@ -290,15 +293,6 @@ class Mail
   alias each_value each_field
 
 
-  def direct_fetch( key )       # undoc
-    @header[key.downcase]
-  end
-
-  def direct_store( key, val )  # undoc
-    @header[key.downcase] = val
-  end
-
-
   def clear
     @header.clear
   end
